pub enum Constraint<'a> {
Extension(&'a str),
Glob(&'a str),
Parts(&'a [&'a str]),
Text(&'a str),
Exclude(&'a [&'a str]),
PathSegment(&'a str),
FilePath(&'a str),
FileType(&'a str),
GitStatus(GitStatusFilter),
Not(Box<Constraint<'a>>),
}Expand description
Constraint types that can be extracted from a query
Variants
Extension(&'a str)
Match file extension: *.rs -> Extension(“rs”)
Glob(&'a str)
Glob pattern: /*.rs -> Glob(“/*.rs”)
Parts(&'a [&'a str])
Multiple text search parts: [“src”, “name”] Uses slice to avoid allocation
Text(&'a str)
Single text token (optimized case)
Exclude(&'a [&'a str])
Exclude pattern: !test -> Exclude(&[“test”])
PathSegment(&'a str)
Path constraint: /src/ -> PathSegment(“src”)
FilePath(&'a str)
File path constraint (AI mode): “libswscale/input.c” → FilePath(“libswscale/input.c”)
Matches files whose relative path ends with this suffix at a / boundary.
FileType(&'a str)
File type constraint: type:rust -> FileType(“rust”)
GitStatus(GitStatusFilter)
Git status constraint: status:modified -> GitStatus(Modified)
Not(Box<Constraint<'a>>)
Negation constraint: !extension:rs -> Not(Extension(“rs”)) Negates the inner constraint